@@ -80,6 +80,7 @@ __all__ = [
     "get_file_size_formatted",
     "get_filename",
     "get_parent_dir",
+    "get_permissions",
     "get_unique_name",
     "is_dir",
     "is_empty",
@@ -113,6 +114,7 @@ __all__ = [
     "replace_file",
     "search_dirs",
     "search_files",
+    "set_permissions",
     "split_filename",
     "split_filepath",
     "split_path",
@@ -788,6 +790,17 @@ def get_parent_dir(path: PathIn, *, levels: int = 1) -> str:
     return join_path(path, *([os.pardir] * max(1, levels)))
 
 
+def get_permissions(path: PathIn) -> int:
+    """
+    Get the file/directory permissions.
+    """
+    path = _get_path(path)
+    assert_exists(path)
+    st_mode = os.stat(path).st_mode
+    permissions = int(str(oct(st_mode & 0o777))[2:])
+    return permissions
+
+
 def get_unique_name(
     path: PathIn,
     *,
@@ -797,7 +810,7 @@ def get_unique_name(
     separator: str = "-",
 ) -> str:
     """
-    Gets a unique name for a directory/file ath the given directory path.
+    Get a unique name for a directory/file ath the given directory path.
     """
     path = _get_path(path)
     assert_dir(path)
@@ -1282,6 +1295,16 @@ def search_files(path: PathIn, pattern: str = "**/*.*") -> list[str]:
     return _filter_paths(path, _search_paths(path, pattern), predicate=is_file)
 
 
+def set_permissions(path: PathIn, value: int) -> None:
+    """
+    Set the file/directory permissions.
+    """
+    path = _get_path(path)
+    assert_exists(path)
+    permissions = int(str(value), 8) & 0o777
+    os.chmod(path, permissions)
+
+
 def split_filename(path: PathIn) -> tuple[str, str]:
     """
     Split a filename and returns its basename and extension.
@@ -1314,12 +1337,58 @@ def split_path(path: PathIn) -> list[str]:
     return names
 
 
+def _write_file_atomic(
+    path: PathIn,
+    content: str,
+    *,
+    append: bool = False,
+    encoding: str = "utf-8",
+) -> None:
+    path = _get_path(path)
+    mode = "a" if append else "w"
+    if append:
+        content = read_file(path, encoding=encoding) + content
+    dirpath, _ = split_filepath(path)
+    try:
+        with tempfile.NamedTemporaryFile(
+            mode=mode,
+            dir=dirpath,
+            delete=True,
+            encoding=encoding,
+        ) as file:
+            file.write(content)
+            file.flush()
+            os.fsync(file.fileno())
+            temp_path = file.name
+            if exists(path):
+                set_permissions(temp_path, get_permissions(path))
+            os.replace(temp_path, path)
+    except FileNotFoundError:
+        # success - the NamedTemporaryFile has not been able
+        # to remove the temp file on __exit__ because the temp file
+        # has replaced atomically the file at path.
+        pass
+
+
+def _write_file_non_atomic(
+    path: PathIn,
+    content: str,
+    *,
+    append: bool = False,
+    encoding: str = "utf-8",
+) -> None:
+    mode = "a" if append else "w"
+    with open(path, mode, encoding=encoding) as file:
+        file.write(content)
+
+
 def write_file(
     path: PathIn,
     content: str,
     *,
     append: bool = False,
     encoding: str = "utf-8",
+    atomic: bool = False,
 ) -> None:
     """
     Write file with the specified content at the given path.
@@ -1327,14 +1396,20 @@ def write_file(
     path = _get_path(path)
     assert_not_dir(path)
     make_dirs_for_file(path)
-    mode = "a" if append else "w"
-    with open(path, mode, encoding=encoding) as file:
-        file.write(content)
+    write_file_func = _write_file_atomic if atomic else _write_file_non_atomic
+    write_file_func(
+        path,
+        content,
+        append=append,
+        encoding=encoding,
+    )
 
 
 def write_file_json(
     path: PathIn,
     data: Any,
+    encoding: str = "utf-8",
+    atomic: bool = False,
     **kwargs: Any,
 ) -> None:
     """
@@ -1351,4 +1426,10 @@ def write_file_json(
 
     kwargs.setdefault("default", default_encoder)
     content = json.dumps(data, **kwargs)
-    write_file(path, content)
+    write_file(
+        path,
+        content,
+        append=False,
+        encoding=encoding,
+        atomic=atomic,
+    )
