@@ -737,6 +737,12 @@ class fsutil_test_case(unittest.TestCase):
         s = "/root/a/b/c/Document.txt"
         self.assertEqual(fsutil.get_parent_dir(s, levels=6), "/")
 
+    def test_get_permissions(self):
+        path = self.temp_path("a/b/c.txt")
+        fsutil.write_file(path, content="Hello World")
+        permissions = fsutil.get_permissions(path)
+        self.assertEqual(permissions, 644)
+
     def test_get_unique_name(self):
         path = self.temp_path("a/b/c")
         fsutil.create_dir(path)
@@ -1181,6 +1187,13 @@ class fsutil_test_case(unittest.TestCase):
         ]
         self.assertEqual(results, expected_results)
 
+    def test_set_permissions(self):
+        path = self.temp_path("a/b/c.txt")
+        fsutil.write_file(path, content="Hello World")
+        fsutil.set_permissions(path, 777)
+        permissions = fsutil.get_permissions(path)
+        self.assertEqual(permissions, 777)
+
     def test_split_filename(self):
         s = "Document"
         self.assertEqual(fsutil.split_filename(s), ("Document", ""))
@@ -1209,22 +1222,26 @@ class fsutil_test_case(unittest.TestCase):
 
     def test_write_file(self):
         path = self.temp_path("a/b/c.txt")
-        fsutil.write_file(self.temp_path("a/b/c.txt"), content="Hello World")
+        fsutil.write_file(path, content="Hello World")
         self.assertEqual(fsutil.read_file(path), "Hello World")
-        fsutil.write_file(self.temp_path("a/b/c.txt"), content="Hello Jupiter")
+        fsutil.write_file(path, content="Hello Jupiter")
         self.assertEqual(fsutil.read_file(path), "Hello Jupiter")
 
     def test_write_file_atomic(self):
         path = self.temp_path("a/b/c.txt")
-        fsutil.write_file(
-            self.temp_path("a/b/c.txt"), content="Hello World", atomic=True
-        )
+        fsutil.write_file(path, content="Hello World", atomic=True)
         self.assertEqual(fsutil.read_file(path), "Hello World")
-        fsutil.write_file(
-            self.temp_path("a/b/c.txt"), content="Hello Jupiter", atomic=True
-        )
+        fsutil.write_file(path, content="Hello Jupiter", atomic=True)
         self.assertEqual(fsutil.read_file(path), "Hello Jupiter")
 
+    def test_write_file_atomic_permissions_inheritance(self):
+        path = self.temp_path("a/b/c.txt")
+        fsutil.write_file(path, content="Hello World", atomic=False)
+        self.assertEqual(fsutil.get_permissions(path), 644)
+        fsutil.set_permissions(path, 777)
+        fsutil.write_file(path, content="Hello Jupiter", atomic=True)
+        self.assertEqual(fsutil.get_permissions(path), 777)
+
     def test_write_file_with_filename_only(self):
         path = "document.txt"
         fsutil.write_file(path, content="Hello World")
@@ -1241,7 +1258,7 @@ class fsutil_test_case(unittest.TestCase):
             "test_datetime": now,
             "test_decimal": dec,
         }
-        fsutil.write_file_json(self.temp_path("a/b/c.json"), data=data)
+        fsutil.write_file_json(path, data=data)
         self.assertEqual(
             fsutil.read_file(path),
             (
@@ -1262,7 +1279,7 @@ class fsutil_test_case(unittest.TestCase):
             "test_datetime": now,
             "test_decimal": dec,
         }
-        fsutil.write_file_json(self.temp_path("a/b/c.json"), data=data, atomic=True)
+        fsutil.write_file_json(path, data=data, atomic=True)
         self.assertEqual(
             fsutil.read_file(path),
             (
@@ -1276,25 +1293,16 @@ class fsutil_test_case(unittest.TestCase):
 
     def test_write_file_with_append(self):
         path = self.temp_path("a/b/c.txt")
-        fsutil.write_file(self.temp_path("a/b/c.txt"), content="Hello World")
+        fsutil.write_file(path, content="Hello World")
         self.assertEqual(fsutil.read_file(path), "Hello World")
-        fsutil.write_file(
-            self.temp_path("a/b/c.txt"), content=" - Hello Sun", append=True
-        )
+        fsutil.write_file(path, content=" - Hello Sun", append=True)
         self.assertEqual(fsutil.read_file(path), "Hello World - Hello Sun")
 
     def test_write_file_with_append_atomic(self):
         path = self.temp_path("a/b/c.txt")
-        fsutil.write_file(
-            self.temp_path("a/b/c.txt"), content="Hello World", atomic=True
-        )
+        fsutil.write_file(path, content="Hello World", atomic=True)
         self.assertEqual(fsutil.read_file(path), "Hello World")
-        fsutil.write_file(
-            self.temp_path("a/b/c.txt"),
-            content=" - Hello Sun",
-            append=True,
-            atomic=True,
-        )
+        fsutil.write_file(path, content=" - Hello Sun", append=True, atomic=True)
         self.assertEqual(fsutil.read_file(path), "Hello World - Hello Sun")
 
 
